==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/uikit/UIPanGestureRecognizer.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 3.2 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("UIKit") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/UIPanGestureRecognizer/*</name>*/ 
    extends /*<extends>*/UIGestureRecognizer/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class UIPanGestureRecognizerPtr extends Ptr<UIPanGestureRecognizer, UIPanGestureRecognizerPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(UIPanGestureRecognizer.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public UIPanGestureRecognizer() {}
    protected UIPanGestureRecognizer(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    
    public UIPanGestureRecognizer(OnGestureListener listener) {
        super(listener);
    }
    
    /*<properties>*/
    @Property(selector = "minimumNumberOfTouches")
    public native @MachineSizedUInt long getMinimumNumberOfTouches();
    @Property(selector = "setMinimumNumberOfTouches:")
    public native void setMinimumNumberOfTouches(@MachineSizedUInt long v);
    @Property(selector = "maximumNumberOfTouches")
    public native @MachineSizedUInt long getMaximumNumberOfTouches();
    @Property(selector = "setMaximumNumberOfTouches:")
    public native void setMaximumNumberOfTouches(@MachineSizedUInt long v);
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "translationInView:")
    public native @ByVal CGPoint getTranslation(UIView view);
    @Method(selector = "setTranslation:inView:")
    public native void setTranslation(@ByVal CGPoint translation, UIView view);
    @Method(selector = "velocityInView:")
    public native @ByVal CGPoint getVelocity(UIView view);
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/uikit/UIPanGestureRecognizer.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
import org.robovm.apple.cloudkit.*;
import org.robovm.apple.fileprovider.*;
import org.robovm.apple.intents.*;
import org.robovm.apple.usernotifications.*;
import org.robovm.apple.linkpresentation.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Library("UIKit") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/UIPanGestureRecognizer/*</name>*/ 
    extends /*<extends>*/UIGestureRecognizer/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class UIPanGestureRecognizerPtr extends Ptr<UIPanGestureRecognizer, UIPanGestureRecognizerPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(UIPanGestureRecognizer.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public UIPanGestureRecognizer() {}
    protected UIPanGestureRecognizer(Handle h, long handle) { super(h, handle); }
    protected UIPanGestureRecognizer(SkipInit skipInit) { super(skipInit); }
    @Method(selector = "initWithTarget:action:")
    public UIPanGestureRecognizer(NSObject target, Selector action) { super(target, action); }
    @Method(selector = "initWithCoder:")
    public UIPanGestureRecognizer(NSCoder coder) { super(coder); }
    /*</constructors>*/
    
    public UIPanGestureRecognizer(OnGestureListener listener) {
        super(listener);
    }
    
    /*<properties>*/
    @Property(selector = "minimumNumberOfTouches")
    public native @MachineSizedUInt long getMinimumNumberOfTouches();
    @Property(selector = "setMinimumNumberOfTouches:")
    public native void setMinimumNumberOfTouches(@MachineSizedUInt long v);
    @Property(selector = "maximumNumberOfTouches")
    public native @MachineSizedUInt long getMaximumNumberOfTouches();
    @Property(selector = "setMaximumNumberOfTouches:")
    public native void setMaximumNumberOfTouches(@MachineSizedUInt long v);
    /**
     * @since Available in iOS 13.4 and later.
     */
    @Property(selector = "allowedScrollTypesMask")
    public native UIScrollTypeMask getAllowedScrollTypesMask();
    /**
     * @since Available in iOS 13.4 and later.
     */
    @Property(selector = "setAllowedScrollTypesMask:")
    public native void setAllowedScrollTypesMask(UIScrollTypeMask v);
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "translationInView:")
    public native @ByVal CGPoint getTranslation(UIView view);
    @Method(selector = "setTranslation:inView:")
    public native void setTranslation(@ByVal CGPoint translation, UIView view);
    @Method(selector = "velocityInView:")
    public native @ByVal CGPoint getVelocity(UIView view);
    /*</methods>*/
}
